@@ -1,5 +1,5 @@
 Density <-
-function(x, data=d, rows=NULL,
+function(x, data=d, filter=NULL,
          n_cat=getOption("n_cat"), Rmd=NULL,
 
        bw=NULL, type=c("general", "normal", "both"),
@@ -130,8 +130,8 @@ function(x, data=d, rows=NULL,
       data.vars <- as.list(seq_along(data))
       names(data.vars) <- names(data)
       ind <- eval(substitute(x), envir=data.vars)  # col num of each var
-      if (!missing(rows)) {  # subset rows
-        r <- eval(substitute(rows), envir=data, enclos=parent.frame())
+      if (!missing(filter)) {  # subset rows
+        r <- eval(substitute(filter), envir=data, enclos=parent.frame())
         r <- r & !is.na(r)  # set missing for a row to FALSE
         data <- data[r,,drop=FALSE]
       }
