@@ -1,5 +1,5 @@
 PieChart <-
-function(x, y=NULL, data=d, rows=NULL,
+function(x, y=NULL, data=d, filter=NULL,
 
          radius=1, hole=0.65, hole_fill=getOption("panel_fill"),
 
@@ -151,8 +151,8 @@ function(x, y=NULL, data=d, rows=NULL,
     data.vars <- as.list(seq_along(data))
     names(data.vars) <- names(data)
     ind <- eval(substitute(x), envir=data.vars)  # col num of each var
-    if (!missing(rows)) {  # subset rows
-      r <- eval(substitute(rows), envir=data, enclos=parent.frame())
+    if (!missing(filter)) {  # subset rows
+      r <- eval(substitute(filter), envir=data, enclos=parent.frame())
       r <- r & !is.na(r)  # set missing for a row to FALSE
       data <- data[r,,drop=FALSE]
     }
